'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends2 = require('babel-runtime/helpers/extends');

var _extends3 = _interopRequireDefault(_extends2);

var _regenerator = require('babel-runtime/regenerator');

var _regenerator2 = _interopRequireDefault(_regenerator);

var _asyncToGenerator2 = require('babel-runtime/helpers/asyncToGenerator');

var _asyncToGenerator3 = _interopRequireDefault(_asyncToGenerator2);

var formatFilesFromArgv = function () {
  var _ref = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee(_ref2) {
    var fileGlobs = _ref2._,
        enableLog = _ref2.log,
        sillyLogs = _ref2.sillyLogs,
        stdin = _ref2.stdin,
        write = _ref2.write,
        eslintPath = _ref2.eslintPath,
        prettierPath = _ref2.prettierPath;
    var prettierESLintOptions, cliOptions;
    return _regenerator2.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            prettierESLintOptions = { disableLog: !enableLog, sillyLogs, eslintPath, prettierPath };
            cliOptions = { write };

            if (!stdin) {
              _context.next = 6;
              break;
            }

            return _context.abrupt('return', formatStdin(prettierESLintOptions));

          case 6:
            return _context.abrupt('return', formatFilesFromGlobs(fileGlobs, cliOptions, prettierESLintOptions));

          case 7:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  return function formatFilesFromArgv(_x) {
    return _ref.apply(this, arguments);
  };
}();

var formatStdin = function () {
  var _ref3 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee2(prettierESLintOptions) {
    var stdinValue, formatted;
    return _regenerator2.default.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return (0, _getStdin2.default)();

          case 2:
            stdinValue = _context2.sent.trim();
            _context2.prev = 3;
            formatted = (0, _prettierEslint2.default)((0, _extends3.default)({ text: stdinValue }, prettierESLintOptions));

            console.log(formatted);
            return _context2.abrupt('return', Promise.resolve(formatted));

          case 9:
            _context2.prev = 9;
            _context2.t0 = _context2['catch'](3);

            logError('There was a problem trying to format the stdin text', _context2.t0.stack);
            return _context2.abrupt('return', Promise.resolve(stdinValue));

          case 13:
          case 'end':
            return _context2.stop();
        }
      }
    }, _callee2, this, [[3, 9]]);
  }));

  return function formatStdin(_x2) {
    return _ref3.apply(this, arguments);
  };
}();

var formatFilesFromGlobs = function () {
  var _ref4 = (0, _asyncToGenerator3.default)(_regenerator2.default.mark(function _callee3(fileGlobs, cliOptions, prettierESLintOptions) {
    var concurrentGlobs, concurrentFormats;
    return _regenerator2.default.wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            concurrentGlobs = 3;
            concurrentFormats = 10;
            return _context3.abrupt('return', new Promise(function (resolve) {
              var successes = [];
              var failures = [];
              _Rx2.default.Observable.from(fileGlobs).mergeMap(getFilesFromGlob, null, concurrentGlobs).concatAll().distinct().mergeMap(function (filePath) {
                return formatFile(filePath, prettierESLintOptions, cliOptions);
              }, null, concurrentFormats).subscribe(function onNext(info) {
                if (info.error) {
                  failures.push(info);
                } else {
                  successes.push(info);
                }
              }, function onError(error) {
                logError('There was an unhandled error while formatting the files', error.stack);
                resolve({ error, successes, failures });
              }, function onComplete() {
                if (successes.length) {
                  var count = _chalk2.default.bold(successes.length);
                  console.log(`${ _chalk2.default.green('success') } formatting ${ count } files with prettier-eslint`);
                }
                if (failures.length) {
                  var _count = _chalk2.default.bold(failures.length);
                  console.log(`${ _chalk2.default.red('failure') } formatting ${ _count } files with prettier-eslint`);
                }
                resolve({ successes, failures });
              });
            }));

          case 3:
          case 'end':
            return _context3.stop();
        }
      }
    }, _callee3, this);
  }));

  return function formatFilesFromGlobs(_x3, _x4, _x5) {
    return _ref4.apply(this, arguments);
  };
}();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _glob = require('glob');

var _glob2 = _interopRequireDefault(_glob);

var _Rx = require('rxjs/Rx');

var _Rx2 = _interopRequireDefault(_Rx);

var _prettierEslint = require('prettier-eslint');

var _prettierEslint2 = _interopRequireDefault(_prettierEslint);

var _chalk = require('chalk');

var _chalk2 = _interopRequireDefault(_chalk);

var _getStdin = require('get-stdin');

var _getStdin2 = _interopRequireDefault(_getStdin);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/* eslint no-console:0 */
var rxGlob = _Rx2.default.Observable.bindNodeCallback(_glob2.default);
var rxReadFile = _Rx2.default.Observable.bindNodeCallback(_fs2.default.readFile);
var rxWriteFile = _Rx2.default.Observable.bindNodeCallback(_fs2.default.writeFile);

exports.default = formatFilesFromArgv;


function getFilesFromGlob(fileGlob) {
  var globOptions = { ignore: [] };
  if (!fileGlob.includes('node_modules')) {
    // basically, we're going to protect you from doing something
    // not smart unless you explicitly include it in your glob
    globOptions.ignore.push('**/node_modules/**');
  }
  return rxGlob(fileGlob, globOptions);
}

function formatFile(filePath, prettierESLintOptions, cliOptions) {
  var fileInfo = { filePath };
  var format$ = rxReadFile(filePath, 'utf8').map(function (text) {
    fileInfo.text = text;
    fileInfo.formatted = (0, _prettierEslint2.default)((0, _extends3.default)({ text, filePath }, prettierESLintOptions));
    return fileInfo;
  });

  if (cliOptions.write) {
    format$ = format$.mergeMap(function (info) {
      return rxWriteFile(filePath, info.formatted).map(function () {
        return fileInfo;
      });
    });
  } else {
    format$ = format$.map(function (info) {
      console.log(info.formatted);
      return info;
    });
  }

  return format$.catch(function (error) {
    return _Rx2.default.Observable.of(Object.assign(fileInfo, { error }));
  });
}

function logError() {
  var _console;

  for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }

  (_console = console).error.apply(_console, ['prettier-eslint-cli error:'].concat(args));
}